<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Klicken, um zur Anwendung zurückzukehren</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Bereinigen</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 Objekte</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Anhalten</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Podcast in YouTube veröffentlichen</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Board</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumente</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Stylus</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Strg+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Hintergründe</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Hintergrund ändern</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig machen</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Strg+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Strg+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorherige</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Vorherige Seite</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Seite nach oben</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Nächste Seite</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Seite nach unten</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Dokumente verwalten</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Strg+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Web-Browsing</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Strg+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Strichstärke</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Dünner Strich</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Mittelstarker Strich</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Dicker Strich</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Kleiner Radiergummi</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Mittelgroßer Radiergummi</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Großer Radiergummi</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Farbe</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Diese Seite neu laden</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Startseite</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Startseite laden</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Lesezeichen anzeigen</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Board anzeigen</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Strg+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Inhalt löschen</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Einstellungen anzeigen</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliothek</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Bibliothek anzeigen</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Strg+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Desktop anzeigen</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Computer-Desktop anzeigen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Strg+Umschalt+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Größer</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Vergrößern</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Strg ++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Kleiner</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Verkleinern</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Strg +-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Neuer Ordner</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Neuen Ordner erstellen</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Neues Dokument</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Neues Dokument erstellen</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Dokument importieren</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Dokument exportieren</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Im Board öffnen</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Seite im Board öffnen</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Strg+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Ausgewählten Inhalt kopieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Ausgewählten Inhalt löschen</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Zu Arbeitsdokument hinzufügen</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Ausgewählten Inhalt geöffnetem Dokument hinzufügen</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Inhalt dem Dokument hinzufügen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Inhalt umbenennen</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Extras</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Extras anzeigen</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Mehrere Bildschirme</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Breitbildformat (16:9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Dokument im Breitbildformat verwenden (16:9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Reguläre Größe (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Reguläre Dokumentgröße (4:3) verwenden</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Benutzerdefinierte Größe</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Benutzerdefinierte Dokumentgröße verwenden</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Ladevorgang anhalten</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Laden der Webseite anhalten</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Bereitschaftsbetrieb</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Präsentation in Bereitschaftsbetrieb versetzen</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuelle Tastatur</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Virtuelle Tastatur anzeigen</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Heller Hintergrund, einfach</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Hell</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Hell karierten Hintergrund</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Dunkler Hintergrund, einfarbig</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Dunkel</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Dunkel karierten Hintergrund</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Präsentation als Video aufnehmen</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Aufnehmen</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Bildschirmaufnahme beginnen</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Objekte löschen</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Alle Objekte löschen</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Anmerkungen löschen</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Alle Anmerkungen löschen</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Seite löschen</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Alle Elemente löschen</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Dokument kommentieren</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Strg+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Anmerkung löschen</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Strg+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marker</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Hervorheben </translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Strg+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Auswahl</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Objekte auswählen und ändern</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Strg+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Zeiger</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Blättern</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Laserpointer</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Virtueller Laserpointer</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Strg+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Linien zeichnen</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Strg+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Text schreiben</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Strg+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Erfassen</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Teil des Bildschirms erfassen</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Zu dieser Seite hinzufügen</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Objekt zu dieser Seite hinzufügen</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Zu neuer Seite hinzufügen</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Objekt zu neuer Seite hinzufügen</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Zur Bibliothek hinzufügen</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Objekt zur Bibliothek hinzufügen</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Seiten</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Neue Seite erstellen</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Neue Seite</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Seite kopieren</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Diese Seite kopieren</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Seite importieren</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Externe Seite importieren</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Podcast-Aufnahme unterbrechen</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Podcast konfigurieren</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Podcast-Aufnahme konfigurieren</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="vanished">Einblendung einfangen</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="vanished">Eingeblendeten Inhalt einfangen</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Internet einfangen</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Webinhalt einfangen</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Benutzerdefinierte Erfassung</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Fenster erfassen</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Fenster erfassen</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Web-Inhalt einbinden</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Integrierbaren Webinhalt erfassen</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Auf dem Bildschirm anzeigen</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Hauptfenster auf dem Bildschirm anzeigen</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Alle Anmerkungen löschen</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>eduMedia-Simulation importieren</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Update überprüfen</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Strg+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>OpenBoard verlassen</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>OpenBoard ausblenden</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>OpenBoard ausblenden</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Mit Objekten interagieren</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Hintergrund löschen</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Hintergrund entfernen</translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation>Anleitung öffnen</translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation>Öffnen der Anleitung im Internet</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation>Heller linierter Hintergrund</translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation>Dunkler linierter Hintergrund</translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation>Rastergröße zurücksetzen</translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation>Kleiner Radiergummi</translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation>Farbe 1</translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation>Farbe 2</translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation>Farbe 3</translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation>Farbe 4</translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation>Farbe 5</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation>Gitter-Zwischenlinien zeichnen</translation>
    </message>
    <message>
        <source>Capture Web Content</source>
        <translation>Webinhalte erfassen</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Authentifizierung erforderlich</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Proxy-Authentifizierung</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Mit Proxy verbinden</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Benutzername und Passwort zur weiteren Verwendung speichern</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>Element ID = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Inhalt wird im Zielformat nicht unterstützt.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Seite entfernen</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Wollen Sie wirklich die ausgewählte Seite des Dokuments &apos;%0&apos; entfernen?</translation>
    </message>
    <message>
        <source>Loading scene (%1/%2)</source>
        <translation>Laden der Szene (%1/%2)</translation>
    </message>
    <message>
        <source>Moving cached scenes (%1/%2)</source>
        <translation>Verschieben von zwischengespeicherten Szenen (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Seitengröße</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
        <translation>Ihre UBX-Datei kann nicht direkt geöffnet werden. Bitte importieren Sie die Datei im Dokumentenmodus</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Browser</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Neue Aktualisierung verfügbar, möchten Sie auf die Internetseite gehen?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Keine Aktualisierung verfügbar</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Aktualisierung verfügbar</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualisierung</translation>
    </message>
    <message>
        <source>Board drawing...</source>
        <translation type="vanished">Brettzeichnung...</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation>Gittergrösse</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation>Gitter-Zwischenlinien zeichnen</translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Fehler beim Herunterladen von %1</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Herunterladen beendet</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Programmtyp %1 unbekannt</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Unbekannter Inhalt %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Objekt hinzufügen</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Alle unterstützt (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Seite %1 des Dokuments löschen</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Seite %1 gelöscht</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Dokument hinzufügen fehlgeschlagen: Fehler beim Kopieren</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppieren</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Gruppierung auflösen</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation>Dokument wird gespeichert...</translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation>Dokument wurde gespeichert...</translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation>Seite %1 löschen</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Fehler beim Hinzufügen des Bildes zur Bibliothek</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>erfasstes Bild</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation>Ladeseite (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Cache-Eigenschaften</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Form:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Teil des Bildschirms erfassen</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Bildschirm erfassen</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Stylus-Palette anzeigen</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Board auf zweitem Bildschirm anzeigen</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Desktop auf zweitem Bildschirm anzeigen</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation>Zeige OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Neuer Ordner</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Seite %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Ordner mit Bildern hinzufügen</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Bilder hinzufügen</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Seiten aus der Datei hinzufügen</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Dokument %1 wird dupliziert</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Dokument %1 kopiert</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Seite entfernen</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Dokument entfernen</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Möchten Sie das Dokument &apos;%1&apos; wirklich entfernen?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Papierkorb leeren</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Möchten Sie den Papierkorb wirklich leeren?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Papierkorb wird geleert</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Papierkorb wurde geleert</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Ordner entfernen</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Möchten Sie den Ordner &apos;%1 und seinen gesamten Inhalt wirklich entfernen?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Kein Dokument ausgewählt!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Unterstützte Datei öffnen</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Datei %1 wird importiert...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Datei konnte nicht importiert werden...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Alle Bilder aus dem Ordner importieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papierkorb</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Dokument öffnen</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Alle Bilder dem Dokument hinzufügen</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Alle Bilder (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>Auswahl enthält keine Bilddateien!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Wollen Sie wirklich %n Seite vom ausgewählten Dokument &apos;%1&apos; entfernen?</numerusform>
            <numerusform>Wollen Sie wirklich %n Seiten vom ausgewählten Dokument &apos;%1&apos; entfernen?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>Das Verzeichnis enthält keine Bilder</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Unbenanntes Dokument</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation>Das Dokument &apos;%1&apos; wurde mit einer neueren Version von OpenBoard erstellt (%2). Beim Öffnen können einige Informationen verloren gehen. Möchten Sie fortfahren?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove all selected documents?</source>
        <translation type="vanished">Möchten sie wirklich alle ausgewählten Dokumente entfernen?</translation>
    </message>
    <message>
        <source>Remove multiple documents</source>
        <translation type="vanished">Mehrere Dokumente entfernen</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation>
            <numerusform>%1 Seite wurde kopiert</numerusform>
            <numerusform>%1 Seiten wurden kopiert</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Objekte löschen</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>Möchten Sie die ausgewählten Elemente wirklich entfernen ?</translation>
    </message>
    <message>
        <source>Title page</source>
        <translation>Titelseite</translation>
    </message>
    <message>
        <source>Empty My Documents</source>
        <translation type="vanished">Eigene Dokumente leeren</translation>
    </message>
    <message>
        <source>Refreshing Document Thumbnails View (%1/%2)</source>
        <translation>Aktualisieren der Vorschauen im Dokumentenmodus (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>Objekte</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>Steuerelemente</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Alle unterstützten Dateien (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Datei %1 gespeichert</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Hinzufügen der Seite %1 von %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import erfolgreich.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Import der Datei %1 erfolgreich.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Datei %1 wird importiert</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Seite %0</translation>
    </message>
    <message>
        <source>Generating thumbnails for board (%1/%2)</source>
        <translation>Erstellen von Voransichten des Tabellenmodus (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">Export fehlgeschlagen.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation>Akzeptieren</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation>Der Name %1 wird bereits benutzt.
Wenn Sie den Namen behalten möchten, wird das Dokument ersetzt.
Wenn Sie einen neuen Namen wählen, wird ein neues Dokument erstellt.</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>My documents</source>
        <translation>Eigene Dokumente</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papierkorb</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 Seite wurde kopiert</numerusform>
            <numerusform>%1 Seiten wurden kopiert</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 Seite wurde kopiert</numerusform>
            <numerusform>%1 Seiten wurden kopiert</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Objekte löschen</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>Möchten Sie die ausgewählten Elemente wirklich entfernen ?</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation>Seite %1/%2 wird kopiert</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (Kopie)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Seite %1/%2 wird kopiert</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 Seite wurde kopiert</numerusform>
            <numerusform>%1 Seiten wurden kopiert</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Dateien werden heruntergeladen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation>Seite %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation>Seite %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Warnungen beim Exportieren aufgetreten</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Dokument wird exportiert...</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Export fehlgeschlagen</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation>Export im ausgewählten Zielpfad nicht möglich. Sie haben nicht die erforderliche Berechtigung um die Datei zu speichern.</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation>Export fehlgeschlagen: Zielpfad nicht beschreibbar</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export erfolgreich.</translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Exportieren nach IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exportieren als IWB-Datei</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Dokument wird exportiert...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export erfolgreich.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export fehlgeschlagen.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Seite</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Als UBZ-Datei exportieren</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Dokument wird exportiert...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export erfolgreich.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>%1 %2 von %3 werden exportiert</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation>In das OpenBoard Format exportieren</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="vanished">Export fehlgeschlagen: Zielpfad nicht beschreibbar</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="vanished">Export fehlgeschlagen</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="vanished">Export im ausgewählten Zielpfad nicht möglich. Sie haben nicht die erforderliche Berechtigung um die Datei zu speichern.</translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Failed to export...</source>
        <translation>Export fehlgeschlagen...</translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation>Als UBX-Datei exportieren</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Dokument wird exportiert...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export erfolgreich.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation>In das UBX OpenBoard Format exportieren</translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Als PDF-Datei exportieren</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Dokument wird exportiert...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export erfolgreich.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>In PDF-Datei exportieren</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="vanished">Export fehlgeschlagen: Zielpfad nicht beschreibbar.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="vanished">Export fehlgeschlagen</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="vanished">Export im ausgewählten Zielpfad nicht möglich. Sie haben nicht die erforderliche Berechtigung um die Datei zu speichern.</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Export als PDF-Datei</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Dokument wird exportiert...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export erfolgreich.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Seite %1 von %2 wird exportiert</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>In PDF-Datei exportieren</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Seite</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Als Web-Datei exportieren</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Dokument wird exportiert...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export erfolgreich.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>In Web-Browser exportieren</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Zur Seite hinzufügen</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Als Hintergrund festlegen</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Zur Bibliothek hinzufügen</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Objektinformationen</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Zu Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Teilen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Zurück zum Ordner</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Aus Favoritenliste entfernen</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Neuen Ordner erstellen</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Dateisystem neu einlesen</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>Importiertes Bild</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Audiodateien</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filme</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animationen</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interaktivitäten</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Anwendungen</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Formen</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Websuche</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papierkorb</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Akzeptieren</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Geben Sie den Namen des Verzeichnisses ein</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Laden </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Gesperrt</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Auf erweitertem Bildschirm sichtbar</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Gesperrt</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Auf erweitertem Bildschirm sichtbar</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Gehen Sie zum ursprünglichen Inhalt</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation>Als Hintergrund einfügen</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation>Medienquelle konnte nicht aufgelöst werden</translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation>Medienformat wird nicht unterstützt</translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation>Dienst zum Abspielen von Mediainhalten nicht gefunden</translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation>Medienfehler: </translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Text hier eintippen&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Schriftfarbe</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Editierbar</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Lädt...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Fixiert</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>In Werkzeug umwandeln</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Standard-Dateiformat (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Datei %1 wird importiert...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Import der Datei %1 fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import erfolgreich.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Import fehlgeschlagen.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Datei %1 wird importiert...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import erfolgreich.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Import  der Datei %1 fehlgeschlagen.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation>OpenBoard (*.ubz)</translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation>Openboard (Dokumentensammlung) (*.ubx)</translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Bildformat (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>PDF-Import fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Seite %1 von %2 wird importiert</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Fehler bei der Videoveröffentlichung im Intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Veröffentlichung im Intranet läuft %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Veröffentlichen</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Eingabe</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Benutzername und Passwort für &quot;%1&quot; bei %2 eingeben&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Verbindung mit Proxy konnte nicht hergestellt werden</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>SSL-Fehler:

%1

%2

Möchten Sie diese Fehler für diesen Computer ignorieren?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation>Geöffnete Open-Sankore Dokumente festgestellt</translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation>Diesen Dialog erneut anzeigen</translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation>Sie können jederzeit im Einstellungsdialog im Menü &quot;Über&quot; auf den OpenBoard Document Importer zugreifen. Warnung, falls sie bereits Ihre Open-Sankore Daten importiert haben, können Sie Ihre aktuellen OpenBoard Dokumente verlieren.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation>Fortfahren</translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation>Auf Ihrem Computer befinden sich Open-Sankoré Dokumente. Um diese in OpenBoard zu importieren drücken Sie den &quot;Fortfahren&quot; Knopf um die Importanwendung zu starten.</translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(Kopie)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Verlust des Dokumentenarchivs</translation>
    </message>
    <message>
        <source>has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="vanished">Verbindung zum Dokumentenarchiv verloren. Um fehlerhafte Daten zu vermeiden muss die Anwendung leider geschlossen werden. Letzte Änderungen können auch verloren gehen.</translation>
    </message>
    <message>
        <source>saving document thumbnail for the page %1</source>
        <translation type="obsolete">Backup Übersichtsseite %1</translation>
    </message>
    <message>
        <source>Saving thumbnail of page %1</source>
        <translation type="vanished">Miniaturansicht der Seite %1 speichern</translation>
    </message>
    <message>
        <source>Moving page to trash folder...</source>
        <translation type="vanished">Die Seite in den Papierkorb verschieben...</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation>Openboard hat den Zugang zum Dokumentenarchiv &apos;%1&apos; verloren. Die Anwendung muss leider beendet werden, um Datenkorruption zu vermeiden. Der Verlust kürzlich vorgenommener Änderungen ist möglich.</translation>
    </message>
    <message>
        <source>Renaming pages (%1/%2)</source>
        <translation>Aktualisieren der aktuellen Seitennamen (%1/%2)</translation>
    </message>
    <message>
        <source>Retrieving all your documents (found : %1)</source>
        <translation>Alle Ihre Dokumente werden wiederhergestellt (gefunden: %1)</translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>englisch</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>russisch</translation>
    </message>
    <message>
        <source>German</source>
        <translation>deutsch</translation>
    </message>
    <message>
        <source>French</source>
        <translation>französisch</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>französisch (Schweiz)</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Der Kodierer konnte nicht gestartet werden...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Kein Kodierer für Podcasts verfügbar...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Teil %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>auf Ihrem Desktop...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>in Ordner %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast erstellt %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Fehler bei der Podcast Aufnahme (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Standard-Audioeingang</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Keine Audioaufnahme</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Klein</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mittelgroß</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Voll</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Im Intranet veröffentlichen</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Auf YouTube veröffentlichen</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation>OpenBoard Cast</translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Der Marker ist druckempfindlich</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Proxy-Login</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Passwort:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Dokument im Internet veröffentlichen</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Titel:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Beschreibung:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Veröffentlichen</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Meine Filme</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation>Sichtbar beim nächsten Mal</translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Vorschau in Miniaturansicht wird erstellt...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>Miniaturansicht %1 wird erstellt...</translation>
    </message>
    <message>
        <source>loading thumbnail of page %1</source>
        <translation type="vanished">
Miniaturansicht der Seite %1 wird geladen</translation>
    </message>
    <message>
        <source>Loading thumbnail (%1/%2)</source>
        <translation>Laden der Vorschau (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation>Seite %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Maske</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Lineal</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Zirkel</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Winkelmesser</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Dreieck</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Lupe</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Zwischenspeicher</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation>Achsen</translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Ganze Seite</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Internet</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Dokument-Updater</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>Dateien müssen aktualisiert werden.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Backup-Pfad:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Durchsuchen</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualisierung</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Wählen Sie einen Ordner für Ihre Sicherungskopie</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Dateien erfolgreich aktualisiert!
Bitte starten Sie die Anwendung erneut, um auf die aktualisierten Dokumente zugreifen zu können.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Während des Updates ist ein Fehler aufgetreten. Die Dateien wurden nicht beeinträchtigt.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Ergebnis der Dateien-Aktualisierung</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Dateien werden aktualisiert</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Bitte warten, der Importprozess beginnt gleich...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Später erinnern</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Lädt...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 aufgerufen (Methode=%1, Status=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>YouTube-Authentifizierung fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Fehler beim Hochladen des Videos auf YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Hochladen auf YouTube läuft %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Autos &amp; Fahrzeuge</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Haustiere &amp; Tiere</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Reisen &amp; Ereignisse</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Spiele</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Comedy</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Leute &amp; Blogs</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Nachrichten &amp; Politik</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Unterhaltung</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Bildung</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Anleitung &amp; Anwendung</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Gemeinnützigkeit &amp; Aktivismus</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Wissenschaft &amp; Technologie</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Datei speichern</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Herunterladen abgebrochen %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Fehler beim Öffnen der gespeicherten Datei: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Fehler beim Speichern: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Netzwerkfehler: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>Sekunden</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 verbleibend</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 von %2 (%3/Sekunden) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 von %2 - Beendet</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 Download</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 Downloads</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Vor ein paar Stunden</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 Objekte</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>&amp;Tab Neu</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Tab duplizieren</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>Tab &amp;Schließen</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>&amp;Andere Tabs schließen</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Tab Neu laden</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Alle Tabs neu laden</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Kürzlich geschlossene Tabs</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Unbenannt)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Keine aktuelle Suche</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Aktuelle Suche</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Aktuelle Suche löschen</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Zu aktuellem Dokument hinzufügen</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Fehler beim Laden der Seite: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation>PDF Dokument herunterladen: Möchten Sie die PDF-Datei herunterladen oder sie zum aktuellen OpenBoard Dokument hinzufügen?</translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>In neuem Tab öffnen</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation>Verarbeitung…</translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Podcast in YouTube veröffentlichen</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Stichwörter</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>YouTube-Benutzername</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>YouTube-Passwort</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Durch Klicken auf &apos;Upload&apos;, bestätigen Sie die nötigen Rechte zum Veröffentlichen des Inhalts zu besitzen und die allgemeinen Nutzungsbedingungen von YouTube zu respektieren.&lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation>Zugangsdaten beim Neustarten wiederherstellen</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>Auf hellem Hintergrund</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Auf dunklem Hintergrund</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Deckkraft</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Strichstärke</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Dick</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Dünn</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Der Stift ist druckempfindlich</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation>Ansichtsgrösse von</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-Mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="vanished">Titel</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="vanished">E-Mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="vanished">Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">Beschreibung</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation>OpenBoard Dokumente</translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation>Erstellungsdatum</translation>
    </message>
    <message>
        <source>Update date</source>
        <translation>Änderungsdatum</translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation>Alphabetische Reihenfolge</translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation>Sortierreihenfolge</translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>Version: ...</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Standardeinstellungen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Seite mit externem Browser anzeigen</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Homepage:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuelle Tastatur</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Tastengröße der Tastatur:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Funktionsleiste</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Oben anzeigen (empfohlen für Tablet-PC)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Unten anzeigen (empfohlen für Whiteboards)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Text unterhalb der Tasten anzeigen</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Stylus-Palette</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marker</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Software-Aktualisierung</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Software-Aktualisierung beim Start prüfen</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Lizenzen</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Inhalt der internen Webseite auf Zweit-Bildschirm oder Projektor anzeigen</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Mehrfach-Bildschirm</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Kontroll- und Anzeige-Bildschirm vertauschen</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Betriebsart</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Starten in Betriebsart:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Board</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Schreibtisch</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy Benutzer:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation>Open-Sankoré Importer</translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation>Prüfen, ob Open-Sankoré Daten beim Start importiert werden können</translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation>Benutze System-Tastatur (empfohlen)</translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation>Tastengröße der integrierten virtuellen Tastatur</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>Gitter</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Auf dunklem Hintergrund</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Deckkraft</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Auf hellem Hintergrund</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation>Kontroll- und Anzeige-Bildschirm vertauschen</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation>Dokumentmodus</translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation>Datumsspalte nur in alphabetischer Reihenfolge anzeigen</translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation>Dokumente aus dem Papierkorb löschen, die älter als</translation>
    </message>
    <message>
        <source>days</source>
        <translation>Tage sind</translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation>PDF-Wiedergabe</translation>
    </message>
    <message>
        <source>Enable quality loss to increase zoom performances</source>
        <translation type="vanished">Zulassen eines Qualitätsverlusts zur Erhöhung der Zoomleistung</translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation>Die Zoomgeschwindigkeit verbessern (kann die Renderqualität geringfügig beeinträchtigen)</translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Einblendung festhalten</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="vanished">Wählen Sie eine Einblendung, die festgehalten werden soll</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Anwendungsname</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Anwendung erstellen</translation>
    </message>
    <message>
        <source>Select a content to capture</source>
        <translation>Einen zu erfassenden Inhalt auswählen</translation>
    </message>
</context>
</TS>
